scitChIP_Sep is a package to create matched and separated files for sc-itChIP result fastq files.

Installation:

    pip install scitChIP_Sep

Example:

    itChipSeparate.py -f example.R1.fq.gz -r example.R2.fq.gz -p PREFIX -o OUTFOLDER